==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/LongHandler.h <==
// class gnu.java.beans.decoder.LongHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class d5e6ad40632182f1 gnu_java_beans_decoder_LongHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_LongHandler_H_
#define _JC_gnu_java_beans_decoder_LongHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_LongHandler$sub_refs	_jc_gnu_java_beans_decoder_LongHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$refs	_jc_gnu_java_beans_decoder_LongHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$nonrefs	_jc_gnu_java_beans_decoder_LongHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$object	_jc_gnu_java_beans_decoder_LongHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_LongHandler$vmethods	_jc_gnu_java_beans_decoder_LongHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_LongHandler$vtable	_jc_gnu_java_beans_decoder_LongHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_LongHandler$vtype	_jc_gnu_java_beans_decoder_LongHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_LongHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_LongHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_LongHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_LongHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_LongHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_LongHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_LongHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_LongHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_LongHandler$vmethods	gnu_java_beans_decoder_LongHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_LongHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_LongHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_LongHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_LongHandler$refs {
    _jc_gnu_java_beans_decoder_LongHandler$sub_refs	gnu_java_beans_decoder_LongHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_LongHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs	gnu_java_beans_decoder_LongHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_LongHandler$object {
	_jc_gnu_java_beans_decoder_LongHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_LongHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_LongHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_LongHandler$vtype _jc_gnu_java_beans_decoder_LongHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_LongHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_LongHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_LongHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/LongHandler.h <==
// class gnu.java.beans.decoder.LongHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class d5e6ad40632182f1 gnu_java_beans_decoder_LongHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_LongHandler_H_
#define _JC_gnu_java_beans_decoder_LongHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_LongHandler$sub_refs	_jc_gnu_java_beans_decoder_LongHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$refs	_jc_gnu_java_beans_decoder_LongHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$nonrefs	_jc_gnu_java_beans_decoder_LongHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_LongHandler$object	_jc_gnu_java_beans_decoder_LongHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_LongHandler$vmethods	_jc_gnu_java_beans_decoder_LongHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_LongHandler$vtable	_jc_gnu_java_beans_decoder_LongHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_LongHandler$vtype	_jc_gnu_java_beans_decoder_LongHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_LongHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_LongHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_LongHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_LongHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_LongHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_LongHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_LongHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_LongHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_LongHandler$vmethods	gnu_java_beans_decoder_LongHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_LongHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_LongHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_LongHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_LongHandler$refs {
    _jc_gnu_java_beans_decoder_LongHandler$sub_refs	gnu_java_beans_decoder_LongHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_LongHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_LongHandler$sub_nonrefs	gnu_java_beans_decoder_LongHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_LongHandler$object {
	_jc_gnu_java_beans_decoder_LongHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_LongHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_LongHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_LongHandler$vtype _jc_gnu_java_beans_decoder_LongHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_LongHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_LongHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_LongHandler_H_ */
